@@ -65,6 +65,9 @@
 bold_search <- function(sci = NULL, id = NULL, fuzzy = FALSE,
   dataTypes = 'basic', includeTree=FALSE, response=FALSE, name = NULL, ...) {
 
+  if(!requireNamespace("bold", quietly = TRUE))
+      stop("package 'bold' is reauireed but not available")
+
   pchk(name, "sci")
   if (!is.null(name)) sci <- name
   stopifnot(!is.null(sci) | !is.null(id))
@@ -78,10 +81,10 @@ bold_search <- function(sci = NULL, id = NULL, fuzzy = FALSE,
 }
 
 #' Barcode of Life taxonomic children
-#' 
-#' BEWARE: this function scrapes data from the BOLD website, so may 
+#'
+#' BEWARE: this function scrapes data from the BOLD website, so may
 #' be unstable. That is, one day it may work, and the next it may fail.
-#' Open an issue if you encounter an error: 
+#' Open an issue if you encounter an error:
 #' https://github.com/ropensci/taxize/issues
 #'
 #' @export
